OpenTAXII — OpenTAXII 0.1.6 documentation

# OpenTAXII

Latest stable release is v0.1.6. (Changelog)

OpenTAXII is a robust Python implementation of TAXII Services that delivers rich feature set and friendly pythonic API.

TAXII (Trusted Automated eXchange of Indicator Information) is a collection of specifications defining a set of services and message exchanges used for sharing cyber threat intelligence information between parties. Check TAXII homepage for more information.

Rich feature set

OpenTAXII implements all TAXII services according to TAXII specification (version 1.0 and 1.1). On top of these services, it also delivers additional functionality such as;

- customizable APIs,
- authentication,
- flexible logging.

Designed to be extendable

OpenTAXII architecture follows TAXII specification in its idea of TTA (TAXII transport agent) and TMH (TAXII message handler) components, separating implementations of:

> - Transport layer (Flask based web app)
> - TAXII logic layer (TAXII server/services/message handlers)
> - Persistence layer (extendable Persistence API)
> - Authentication layer (extendable Authentication API)

Documentation contents

- Installation
- Configuration
- Running OpenTAXII
- Docker
- Authentication
- Public code-level APIs
- API reference
- Contributing and developing
- Changelog
- License

External links

- Online documentation (Read the docs)
- Project page with source code and issue tracker (Github)
- Python Package Index (PyPI) page with released tarballs
- EclecticIQ